utils::globalVariables("TuningInstanceSingleCrit")
#' @import checkmate
#' @importFrom R6 R6Class
#' @importFrom mlr3 lrn rsmp msr resample default_measures Task TaskRegr
#' TaskClassif
#' @import mlr3tuning
#' @importFrom mlr3learners LearnerRegrLM
#' @importFrom mlr3misc insert_named
#' @importFrom data.table data.table as.data.table setnafill
#' @importFrom readstata13 read.dta13
#' @importFrom stats formula model.matrix rnorm runif rexp toeplitz pnorm qnorm
#' printCoefmat quantile p.adjust.methods p.adjust median
#' @importFrom mvtnorm rmvnorm
#' @importFrom clusterGeneration genPositiveDefMat
#' @importFrom utils read.table compareVersion packageVersion
#' @importFrom stats complete.cases
#' @importFrom magrittr %>%
#' @importFrom dplyr mutate group_by across all_of ungroup select summarise everything
#' @importFrom MLmetrics RMSE
NULL
